package com.withpersona.sdk2.inquiry

import android.os.Bundle
import androidx.fragment.app.Fragment
import com.withpersona.sdk2.inquiry.internal.InquiryIntentKeys
import com.withpersona.sdk2.inquiry.types.INQUIRY_FRAGMENT_NAME

/**
 * Represents an Inquiry that is meant to be launched inline using [Fragment]s.
 */
class InlineInquiry internal constructor(
  private val inquiry: Inquiry,
  private val requestKey: String?,
  private val isNavBarEnabled: Boolean?,
  private val controlNavigationBar: Boolean?,
  private val controlStatusBar: Boolean?,
) {

  /**
   * For launching a Persona Inquiry "inline" as a fragment.
   *
   * @return a Fragment that can be used to launch an Inquiry. Returns null if the SDK is improperly
   * configured.
   */
  @ExperimentalInlineApi
  fun createFragment(): Fragment? =
    try {
      Class.forName(INQUIRY_FRAGMENT_NAME).getDeclaredConstructor().newInstance() as? Fragment
    } catch (e: ClassNotFoundException) {
      null
    }?.apply {
      arguments = Bundle().apply {
        inquiry.addArgumentsToBundle(this)
        addArgumentsToBundle(this)
      }
    }

  private fun addArgumentsToBundle(bundle: Bundle) {
    with(bundle) {
      requestKey?.let { putString(InquiryIntentKeys.REQUEST_KEY, it) }
      isNavBarEnabled?.let { putBoolean(InquiryIntentKeys.IS_NAV_BAR_ENABLED, it) }
      controlNavigationBar?.let { putBoolean(InquiryIntentKeys.CONTROL_NAVIGATION_BAR, it) }
      controlStatusBar?.let { putBoolean(InquiryIntentKeys.CONTROL_STATUS_BAR, it) }
    }
  }
}