package com.withpersona.sdk2.inquiry

import androidx.fragment.app.FragmentManager
import com.withpersona.sdk2.inquiry.types.DEFAULT_REQUEST_KEY

/**
 * Builder class for [InlineInquiry].
 */
class InlineInquiryBuilder internal constructor(
  private val inquiry: Inquiry,
) {
  private var requestKey: String? = null
  private var isNavBarEnabled: Boolean? = null
  private var controlNavigationBar: Boolean? = null
  private var controlStatusBar: Boolean? = null

  /**
   * Sets the request key to use to get the Inquiry results. See
   * [FragmentManager.setFragmentResultListener] for more details. If [requestKey] is not set or
   * set to null, the request key [DEFAULT_REQUEST_KEY] will be used.
   */
  @ExperimentalInlineApi
  fun requestKey(requestKey: String?): InlineInquiryBuilder =
    this.apply {
      this.requestKey = requestKey
    }

  /**
   * Sets whether the inquiry should show the navigation bar (top toolbar). Defaults to true.
   */
  @ExperimentalInlineApi
  fun isNavBarEnabled(isNavBarEnabled: Boolean): InlineInquiryBuilder =
    this.apply {
      this.isNavBarEnabled = isNavBarEnabled
    }

  /**
   * Sets whether the inquiry screen can change the navigation bar. Defaults to true.
   *
   * Set this to false if you are using a custom footer view.
   */
  @ExperimentalInlineApi
  fun controlNavigationBar(controlNavigationBar: Boolean): InlineInquiryBuilder =
    this.apply {
      this.controlNavigationBar = controlNavigationBar
    }

  /**
   * Sets whether the inquiry screen can change the status bar. Defaults to true.
   *
   * Set this to false if you are using a custom header view.
   */
  @ExperimentalInlineApi
  fun controlStatusBar(controlStatusBar: Boolean): InlineInquiryBuilder =
    this.apply {
      this.controlStatusBar = controlStatusBar
    }

  /**
   * Create the [InlineInquiry] object with the fields set.
   */
  @ExperimentalInlineApi
  fun build(): InlineInquiry = InlineInquiry(
    inquiry = inquiry,
    requestKey = requestKey,
    isNavBarEnabled = isNavBarEnabled,
    controlNavigationBar = controlNavigationBar,
    controlStatusBar = controlStatusBar,
  )
}