package com.withpersona.sdk2.inquiry

import java.util.Date

/**
 * Possible field types returned in [InquiryResponse.Complete]
 */
sealed class InquiryField {
  /**
   * Inquiry field backed by an [Int]
   */
  class IntegerField(val value: Int?) : InquiryField()

  /**
   * Inquiry field backed by a [Boolean]
   */
  class BooleanField(val value: Boolean?) : InquiryField()

  /**
   * Inquiry field backed by a [String]
   */
  class StringField(val value: String?) : InquiryField()

  /**
   * Inquiry field backed by a [Float]
   */
  class FloatField(val value: Float?) : InquiryField()

  /**
   * Inquiry field backed by a [Date] (without time)
   */
  class DateField(val value: Date?) : InquiryField()

  /**
   * Inquiry field backed by a [Date]
   */
  class DatetimeField(val value: Date?) : InquiryField()

  /**
   * Inquiry field backed by a [String] representing a choice
   */
  class ChoicesField(val value: String?) : InquiryField()

  /**
   * Inquiry field backed by a [Array<String>] representing a choice
   */
  class MultiChoicesField(val value: Array<String>?) : InquiryField()

  /**
   * Inquiry field backed by a yet-to-be supported [UnknownField.type]
   */
  class UnknownField(val type: String?) : InquiryField()
}