package com.withpersona.sdk2.inquiry

import com.withpersona.sdk2.inquiry.types.collected_data.CollectedData
import com.withpersona.sdk2.inquiry.types.collected_data.ErrorCode

/**
 * Inquiry flow response parent class. The response will either be [Complete], [Cancel], or [Error].
 */
sealed class InquiryResponse {
  /**
   * Object returned on a completed inquiry
   *
   * @property inquiryId unique Persona-generated identifier for the inquiry
   * @property status result from the Inquiry flow
   * @property fields data extracted from the Inquiry flow
   * @property collectedData data collected from the Inquiry flow. Only returned if return collected
   * data was enabled.
   */
  class Complete(
    val inquiryId: String,
    val status: String,
    val fields: Map<String, InquiryField>,
    val collectedData: CollectedData?,
  ) : InquiryResponse()

  /**
   * Object returned when the individual cancels the inquiry
   *
   * @property inquiryId unique Persona-generated identifier for the inquiry
   * @property sessionToken session for use of resuming Inquiry
   */
  class Cancel(
    val inquiryId: String?,
    val sessionToken: String?,
  ) : InquiryResponse()

  /**
   * Object returned when there is a problem during the Inquiry flow
   *
   * @property debugMessage reason why the Inquiry did not complete correctly
   * @property cause information about an exception if the error was due to an exception
   */
  class Error(
    val debugMessage: String,
    val errorCode: ErrorCode,
    val cause: String?,
  ) : InquiryResponse()
}