package com.withpersona.sdk2.inquiry

import androidx.annotation.StyleRes

/**
 * ThemeSource instructs the SDK to use either client side theming set on the app
 * or server side theming set in the Persona Dashboard.
 */
sealed interface ThemeSource {
  val theme: Int?
}

/**
 * Instructs the SDK to use theme values set on the client.
 * @param theme the style resource to use for theming.
 */
@Deprecated(
  "Client side theming is deprecated, please configure your theme inside the persona dashboard and use ServerThemeSource instead.",
)
class ClientThemeSource(@StyleRes override val theme: Int?) : ThemeSource

/**
 * Instructs the SDK to use theme values set in the Persona Dashboard.
 * @param theme the style resource to fall back to for styles not configurable by the server.
 * (example: the initial loading screen background color that is used before receiving the
 * first network response from the Persona flow).
 */
class ServerThemeSource(@StyleRes override val theme: Int?) : ThemeSource