package com.withpersona.sdk2.inquiry.inline_inquiry

import com.withpersona.sdk2.inquiry.ExperimentalInlineApi

/**
 * Used to control the inquiry flow when launching an inquiry as an inline inquiry.
 *
 * Fragments/Activities that want to control the inquiry flow should implement this interface.
 */
@ExperimentalInlineApi
interface InlineInquiryController {
  /**
   * Called when the inline SDK is ready and attached. The receiver should use [inlineInquiryScreen]
   * to control the flow.
   */
  @ExperimentalInlineApi
  fun onAttached(inlineInquiryScreen: InlineInquiryScreen)

  /**
   * Called when the inline SDK has been detached. References to the [InlineInquiryScreen] should be
   * cleared to prevent leaking resources.
   */
  @ExperimentalInlineApi
  fun onDetached()
}