package com.withpersona.sdk2.inquiry.inline_inquiry

import com.withpersona.sdk2.inquiry.ExperimentalInlineApi
import kotlinx.coroutines.flow.Flow

@ExperimentalInlineApi
interface InlineInquiryScreen {
  /**
   * A flow of the screen state.
   */
  val screenStateFlow: Flow<ScreenState>

  /**
   * A flow of events.
   */
  val eventFlow: Flow<InquiryEvent>

  /**
   * Request the inquiry screen to go to the previous step. If back is not enabled, this will
   * request to cancel the inquiry instead.
   */
  fun goBack()

  /**
   * Request to cancel the inquiry.
   * @param force if true, the inquiry will be cancelled immediately without user acknowledgement.
   * If false, a dialog will be shown to ask the user to confirm.
   */
  fun cancelInquiry(force: Boolean)
}

@ExperimentalInlineApi
data class ScreenState(
  /**
   * Whether the back button should be shown or hidden.
   */
  val shouldShowBackButton: Boolean,

  /**
   * Whether the cancel button should be shown or hidden.
   */
  val shouldShowCancelButton: Boolean,

  /**
   * Whether navigation should be enabled. If false, the navigation UI should be disabled.
   *
   * This is usually set to false when the inquiry is in a loading state.
   */
  val isNavigationEnabled: Boolean,
)