package com.withpersona.sdk2.inquiry.inline_inquiry

import android.os.Parcelable
import com.withpersona.sdk2.inquiry.ExperimentalInlineApi
import kotlinx.parcelize.Parcelize

@ExperimentalInlineApi
sealed interface InquiryEvent : Parcelable {

  /**
   * Triggered when an Inquiry object has been created in the client.
   *
   * Dynamic Flow Templates will send this event at the same time as 'ready', and it will not
   * indicate user interaction.
   */
  @Parcelize
  data class StartEvent(
    val inquiryId: String,
  ) : InquiryEvent

  /**
   * The current page in the Inquiry flow changed. This is primarily used with the Inlined React
   * flow to dynamically resize the widget based on the contents of the current page.
   *
   * page-change events receive a metadata object containing the following fields:
   *
   * @param name name of the next step as configured in the Inquiry Template
   * @param path string representing the step type
   */
  @Parcelize
  data class PageChange(
    val name: String,
    val path: String,
  ) : InquiryEvent
}